ServiceError

Enum ServiceError 

pub enum ServiceError {
    InvalidTransition(&'static str),
    Dependency(&'static str),
    Implementation(&'static str),
}
Generic error type for service operations.

The fabric itself never allocates or performs I/O in order to create error values. Services are free to define richer error enums and convert them into this type if needed.

This type uses &'static str messages to remain allocation-free and no_std-friendly.

Variants



InvalidTransition(&'static str)

The requested transition was not compatible with the current state.



Dependency(&'static str)

A required dependency was not in a compatible state.



Implementation(&'static str)

An implementation-specific failure.